diff dmd/statement.h @ 305:2b72433d5c8c trunk

[svn r326] Fixed a bunch of issues with printf's that MinGW32 did not support. Fixed problems with label collisions when using labels inside inline asm. LabelStatement is now easily reached given its Identifier, which should be useful elsewhere too. Enabled inline asm for building the lib/compiler/llvmdc runtime code, fixing branches out of asm makes this possible.
author lindquist
date Fri, 27 Jun 2008 22:04:35 +0200
parents 3ebc136702dd
children d59c363fccad
line wrap: on
line diff
--- a/dmd/statement.h	Wed Jun 25 23:42:38 2008 +0200
+++ b/dmd/statement.h	Fri Jun 27 22:04:35 2008 +0200
@@ -761,13 +761,12 @@
 
     // LLVMDC
     llvm::BasicBlock* llvmBB;
+    bool asmLabel;       // for labels inside inline assembler
 };
 
 struct LabelDsymbol : Dsymbol
 {
     LabelStatement *statement;
-// LLVMDC
-    bool asmLabel;       // for labels inside inline assembler
 
     LabelDsymbol(Identifier *ident);
     LabelDsymbol *isLabel();
@@ -793,8 +792,8 @@
     void toIR(IRState *irs);
 
     // LLVMDC
-    // non-zero if this is a branch, contains the target
-    LabelDsymbol* isBranchToLabel;
+    // non-zero if this is a branch, contains the target labels identifier
+    Identifier* isBranchToLabel;
 };
 
 struct AsmBlockStatement : CompoundStatement